@@ -1,12 +1,12 @@
 from inspect import isclass
 from itertools import chain
-from typing import Type, Optional, Union, Any
+from typing import Optional, Union, Any, List
 
-from pydantic import BaseModel, create_model, validate_model, Field, ConfigError
+from pydantic import BaseModel, create_model, validate_model, ConfigError
 from pydantic.main import ModelMetaclass
 
+
 import django
-from django.contrib.contenttypes.fields import GenericRelation, GenericForeignKey
 from django.utils.functional import Promise
 from django.utils.encoding import force_str
 from django.core.serializers.json import DjangoJSONEncoder
@@ -18,10 +18,10 @@ _is_base_model_class_defined = False
 
 
 class ModelSchemaJSONEncoder(DjangoJSONEncoder):
-    def default(self, obj):
+    def default(self, obj):  # pragma: nocover
         if isinstance(obj, Promise):
             return force_str(obj)
-        return super().default(obj)  # pragma: nocover
+        return super().default(obj)
 
 
 class ModelSchemaMetaclass(ModelMetaclass):
@@ -60,6 +60,7 @@ class ModelSchemaMetaclass(ModelMetaclass):
                 _seen = set()
 
                 for field in chain(fields, annotations.copy()):
+
                     field_name = getattr(
                         field, "name", getattr(field, "related_name", field)
                     )
@@ -84,6 +85,7 @@ class ModelSchemaMetaclass(ModelMetaclass):
                             and pydantic_field.default_factory
                         ):
                             pydantic_field = pydantic_field.default_factory()
+
                     elif field_name in annotations:
                         python_type = annotations.pop(field_name)
                         pydantic_field = (
@@ -102,9 +104,6 @@ class ModelSchemaMetaclass(ModelMetaclass):
                 )
 
                 setattr(p_model, "instance", None)
-                setattr(p_model, "objects", p_model._objects())
-                setattr(p_model, "get", p_model._get)
-                setattr(p_model, "create", p_model._create)
 
                 return p_model
 
@@ -112,28 +111,6 @@ class ModelSchemaMetaclass(ModelMetaclass):
 
 
 class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
-    def save(self) -> None:
-        cls = self.__class__
-        p_model = cls.from_django(self.instance, save=True)
-        self._ṣet_object(
-            __dict__=p_model.__dict__, __fields_set__=p_model.__fields_set__
-        )
-
-    def refresh(self) -> None:
-        cls = self.__class__
-        instance = cls.objects.get(pk=self.instance.pk)
-        p_model = cls.from_django(instance)
-        self._ṣet_object(
-            __dict__=p_model.__dict__, __fields_set__=p_model.__fields_set__
-        )
-
-    def delete(self) -> None:
-        self.instance.delete()
-        cls = self.__class__
-        cls.instance = None
-        p_model = cls.__new__(cls)
-        self._ṣet_object(__dict__=p_model.__dict__)
-
     @classmethod
     def schema_json(
         cls,
@@ -142,6 +119,7 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
         encoder_cls=ModelSchemaJSONEncoder,
         **dumps_kwargs: Any,
     ) -> str:
+
         return cls.__config__.json_dumps(
             cls.schema(by_alias=by_alias), cls=encoder_cls, **dumps_kwargs
         )
@@ -161,10 +139,6 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
 
         return fields
 
-    def _ṣet_object(self, **kwargs) -> None:
-        object.__setattr__(self, "__dict__", kwargs["__dict__"])
-        object.__setattr__(self, "__fields_set__", kwargs.get("__fields_set__", {}))
-
     @classmethod
     def _get_object_model(cls, obj_data):
         values, fields_set, validation_error = validate_model(cls, obj_data)
@@ -177,30 +151,13 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
 
         return p_model
 
-    @classmethod
-    def _objects(cls) -> django.db.models.manager.Manager:
-        return cls.__config__.model.objects
-
-    @classmethod
-    def _create(cls, **kwargs) -> "ModelSchema":
-        instance = cls.objects.create(**kwargs)
-
-        return cls.from_django(instance)
-
-    @classmethod
-    def _get(cls, **kwargs) -> "ModelSchema":
-        instance = cls.objects.get(**kwargs)
-
-        return cls.from_django(instance)
-
     @classmethod
     def from_django(
         cls: "ModelSchema",
         instance: Union[django.db.models.Model, django.db.models.QuerySet],
         many: bool = False,
         cache: bool = True,
-        save: bool = False,
-    ) -> Union["ModelSchema", "ModelSchemaQuerySet"]:
+    ) -> Union["ModelSchema", List["ModelSchema"]]:
 
         if not many:
             obj_data = {}
@@ -210,6 +167,9 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
             for field in fields:
                 model_cls = None
                 model_cls_fields = None
+
+                # Check if this field is a related model schema to handle the data
+                # according to specific schema rules.
                 if (
                     field.name in annotations
                     and isclass(cls.__fields__[field.name].type_)
@@ -217,6 +177,16 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
                 ):
                     model_cls = cls.__fields__[field.name].type_
                     model_cls_fields = model_cls.get_fields()
+                    related_include = getattr(model_cls.__config__, "include", None)
+                    related_exclude = getattr(model_cls.__config__, "exclude", None)
+                    if related_exclude:
+                        model_cls_fields = [
+                            i for i in model_cls_fields if i not in related_exclude
+                        ]
+                    elif related_include:
+                        model_cls_fields = [
+                            i for i in model_cls_fields if i in related_include
+                        ]
 
                 if not field.concrete and field.auto_created:
                     accessor_name = field.get_accessor_name()
@@ -240,7 +210,7 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
                             related_obj_data = model_cls.construct(
                                 **{
                                     _field: getattr(related_obj, _field)
-                                    for _field in model_cls.get_fields()
+                                    for _field in model_cls_fields
                                 }
                             )
                         else:
@@ -277,30 +247,16 @@ class ModelSchema(BaseModel, metaclass=ModelSchemaMetaclass):
 
             p_model = cls._get_object_model(obj_data)
 
-            if save:
-                instance.save()
             if cache:
                 cls.instance = instance
 
             return p_model
 
-        p_model_list = []
-        for obj in instance:
-            p_model = cls.from_django(obj, cache=False, many=False, save=False)
-            p_model_list.append(p_model)
+        p_model_list = [
+            cls.from_django(obj, cache=False, many=False) for obj in instance
+        ]
 
-        model_name = p_model.__config__.model._meta.model_name
-        model_name_plural = f"{model_name}s"
-
-        fields = {model_name_plural: (list, Field(None, title=f"{model_name_plural}"))}
-        p_model_qs = create_model(
-            "ModelSchemaQuerySet",
-            __base__=BaseModel,
-            __module__=cls.__module__,
-            **fields,
-        )
-
-        return p_model_qs(**{model_name_plural: p_model_list})
+        return p_model_list
 
 
 _is_base_model_class_defined = True
